Previewer: Angle ▲ Prism plugins

# How to use

You don't need to do anything. With this plugin loaded, a previewer will appear on hovering the angle values in code blocks.

This plugin is compatible with CSS, Less, Sass, Scss and Stylus.

# Examples

## CSS

    div {
    	transform: rotate(10deg);
    }

## Less

    @angle: 3rad;
    #header a {
    	transform: rotate(.4turn)
    }

## Sass

    $angle: 380grad
    @mixin foobar
    	transform: rotate(-120deg)
    .foo
    	transform: rotate(18rad)

## Scss

    $angle: 1.8turn;
    .foo {
    	transform: rotate(-3rad)
    }

## Stylus

    angle = 357deg
    .foo
    	transform: rotate(100grad)